# Topsis-Aadil-102017047

It displays the TOPSIS ranking order of the input models.

## Installation

`pip install Topsis-Aadil-101953016`

## How to use it?

Usage: topsis <input_filename.csv> <"Weights"> <"Impacts"> <output_filename.csv>

## License

This repository is licensed under the MIT license. See LICENSE for details.